@@ -15,7 +15,7 @@ a Challonge tournament.
 
 =head1 VERSION
 
-Version 0.11
+Version 0.20
 
 =cut
 
@@ -341,7 +341,7 @@ that has been successfully destroyed.
 
 sub __is_kill
 {
-	print STDERR "Error: Client has been destroyed\n";
+	print STDERR "Error: Participant has been destroyed\n";
 	return undef;
 }
 
@@ -356,6 +356,13 @@ sub __args_are_valid
 {
 	my $args = shift;
 
+	# Check it is a hashref:
+	unless(ref $args eq "HASH")
+	{
+		print STDERR "Error: Argument must be a hashref.\n";
+		return undef;
+	}
+
 	# The possible parameters, grouped together by the kind of input they take.
 	my %valid_args = (
 		string => [
@@ -430,35 +437,31 @@ Please report any bugs or feature requests to C<bug-www-challonge at rt.cpan.org
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Challonge::Participant>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc WWW::Challonge::Participant
 
-
 You can also look for information at:
 
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Challonge::Participant>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Challonge>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/WWW-Challonge::Participant>
+L<http://annocpan.org/dist/WWW-Challonge>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/WWW-Challonge::Participant>
+L<http://cpanratings.perl.org/d/WWW-Challonge>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WWW-Challonge::Participant/>
+L<http://search.cpan.org/dist/WWW-Challonge>
 
 =back
 
@@ -472,11 +475,14 @@ L<http://search.cpan.org/dist/WWW-Challonge::Participant/>
 
 =item L<WWW::Challonge::Match>
 
-=back
+=item L<WWW::Challonge::Match::Attachment>
 
+=back
 
 =head1 ACKNOWLEDGEMENTS
 
+Everyone on the L<Challonge|http://challonge.com> team for making such a great
+service.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -518,7 +524,6 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-
 =cut
 
 1; # End of WWW::Challonge::Participant
