@@ -16,11 +16,11 @@ WWW::Challonge::Tournament - A class representing a single Challonge tournament.
 
 =head1 VERSION
 
-Version 0.11
+Version 0.20
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.20';
 
 =head1 SUBROUTINES/METHODS
 
@@ -860,6 +860,13 @@ sub __args_are_valid
 {
 	my $args = shift;
 
+	# Check it is a hashref:
+	unless(ref $args eq "HASH")
+	{
+		print STDERR "Error: Argument must be a hashref.\n";
+		return undef;
+	}
+
 	# The possible parameters, grouped together by the kind of input they take.
 	my %valid_args = (
 		string => [
@@ -1046,19 +1053,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Challonge::Tournament>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Challonge>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/WWW-Challonge::Tournament>
+L<http://annocpan.org/dist/WWW-Challonge>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/WWW-Challonge::Tournament>
+L<http://cpanratings.perl.org/d/WWW-Challonge>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WWW-Challonge::Tournament/>
+L<http://search.cpan.org/dist/WWW-Challonge>
 
 =back
 
@@ -1072,6 +1079,8 @@ L<http://search.cpan.org/dist/WWW-Challonge::Tournament/>
 
 =item L<WWW::Challonge::Match>
 
+=item L<WWW::Challonge::Match::Attachment>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
@@ -1119,7 +1128,6 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-
 =cut
 
 1; # End of WWW::Challonge::Tournament
